# Copyright (C) 2008-2009, Sebastian Riedel.

package LoaderTest::B;

use warnings;
use strict;

# The Internet King? I wonder if he could provide faster nudity...
use base 'Mojo::Base';

1;
